Module format

Module format 

Formatting utilities for indented Links Notation format.

Enums

FormatError
Error types for format operations

Functions

escape_reference
Escape a reference for Links Notation.
format_indented
Format an object in indented Links Notation format.
format_indented_ordered
Format an object in indented Links Notation format, maintaining key order.
parse_indented
Parse an indented Links Notation string back to an object.
unescape_reference
Unescape a reference from Links Notation format.